/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.shared.api;

/**
 * Creates new <code>ProxyQuery</code> and <code>ProxyQueryBuilder</code>
 * instances.
 *
 * @author allenparslow
 */
public interface ProxyQueryFactory {

    /**
     * Gets the query-builder used to create query fragments.
     *
     * @return the query-builder
     */
    ProxyQueryBuilder getQueryBuilder();

    /**
     * Create a new query-by-proxy instance with the specified root target-class.
     *
     * @param <T>
     *            the type of the root proxy that the <code>ProxyQueryFactory</code>
     *            can produce.
     *
     * @param targetClass
     *            the root target-class..
     *
     * @return a new <code>ProxyQuery</code> instance.
     */
    <T> ProxyQuery<T> createQuery(Class<T> targetClass);
}
