/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.shared.api.model;

import org.cementframework.querybyproxy.shared.api.model.conditionals.Conditional;
import org.cementframework.querybyproxy.shared.api.model.conditionals.GroupConditional;
import org.cementframework.querybyproxy.shared.api.model.conditionals.LogicGate;

/**
 * Represents a "where" clause.
 *
 * @author allenparslow
 */
public class WhereClause extends GroupConditional {
    /**
     * Create a new <code>WhereImpl</code> instance.
     *
     * @param conditionals the conditional-expressions for the where-clause.
     */
    public WhereClause(Conditional... conditionals) {
        super(LogicGate.AND, conditionals);
    }


    /**
     * Create a new <code>WhereImpl</code> instance.
     *
     * @param parent the parent where-clause
     * @param newConditional the conditional to add to the parent
     */
    public WhereClause(GroupConditional parent, Conditional newConditional) {
        super(LogicGate.AND, parent, newConditional);
    }
}
