/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.shared.api.model.joins;


/**
 * An abstract representation of a query-join for a from-clause.
 *
 * @author allenparslow
 */
public abstract class AbstractJoin implements QueryJoin {

    private final QueryJoin parent;
    private final Object targetProxy;
    private final QueryJoinType joinType;
    private final QueryJoinModifier joinModifier;

    protected AbstractJoin(
            QueryJoin parent,
            QueryJoinType joinType,
            QueryJoinModifier joinModifier,
            Object targetProxy) {
        this.parent = parent;
        this.targetProxy = targetProxy;
        this.joinType = joinType;
        this.joinModifier = joinModifier;
    }

    /**
     * {@inheritDoc}
     */
    public QueryJoinType getJoinType() {
        return joinType;
    }

    /**
     * {@inheritDoc}
     */
    public QueryJoin getParent() {
        return parent;
    }

    /**
     * {@inheritDoc}
     */
    public Object getTargetProxy() {
        return targetProxy;
    }

    /**
     * {@inheritDoc}
     */
    public QueryJoinModifier getJoinModifier() {
        return joinModifier;
    }
}
