/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.shared.api.model.joins;


/**
 * Represents a "nested property" join for a from-clause.
 *
 * @author allenparslow
 */
public class NestedPropertyJoin extends AbstractJoin {
    private final String path;

    /**
     * Create a new <code>ProxyJoin</code> instance.
     *
     * @param parent
     *            the parent join.
     * @param joinType
     *            the join-type.
     * @param joinModifier
     *            the fetch-join modifier.
     * @param path
     *            the path to the proxy.
     * @param proxy
     *            the target proxy.
     */
    public NestedPropertyJoin(
            QueryJoin parent,
            QueryJoinType joinType,
            QueryJoinModifier joinModifier,
            String path,
            Object proxy) {
        super(parent, joinType, joinModifier, proxy);
        this.path = path;
    }

    /**
     * Gets the path to the proxy.
     *
     * @return the path to the proxy.
     */
    public String getPath() {
        return path;
    }
}
