/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.shared.api.model.joins;


/**
 * Represents a theta (non-relationship) for a from-clause.
 *
 * <p>
 * Example: "from Entity a1, Entity a2 where a1.id = a2.id"
 * </p>
 *
 * @author allenparslow
 */
public class ThetaJoin extends AbstractJoin {

    private final String name;

    /**
     * Create a new <code>ThetaJoin</code> instance.
     *
     * @param parent
     *            the parent join
     * @param name
     *            the name of the entity
     * @param targetProxy
     *            the target proxy
     */
    public ThetaJoin(QueryJoin parent, String name, Object targetProxy) {
        super(parent, QueryJoinType.THETA, QueryJoinModifier.NONE, targetProxy);
        this.name = name;
    }

    /**
     * The name of the entity for the join.
     *
     * @return the join entity's name.
     */
    public String getName() {
        return name;
    }
}
